Skip to contents

This function creates a WKT (Well-Known Text) representation of a linestring connecting the start and end coordinates of a fishing set from the Andes database.

Usage

make_set_wkt(set)

Arguments

set

A dataframe (single row) containing a fishing set from ANDES database