Skip to contents

rbind, but allow different columns names Make a union of the rows filling missing columns with NA https://stackoverflow.com/questions/3402371/combine-two-data-frames-by-rows-rbind-when-they-have-different-sets-of-columns

Usage

row_union(df1, df2)

Arguments

df1

Dataframe the first dataframe

df2

Dataframe the second dataframe

Value

Combined dataframe