Create an OBISEvent from an Andes fishing set
event_from_fishing_set.RdThis function creates an OBISEvent object representing a fishing set from the ANDES database. It maps certain fields to a corresponding DwC event fields, and addes hard-coded values where necessary.
See also
[get_andes_set()] for getting a list of sets from the Andes DB.
Other OBISEvent creation functions:
event_from_mission()