Get a set dataframe
get_andes_set.RdThis function queries the andes database and returns a dataframe containing the set data. TODO: The mission filter is not yet implemented everywhere, but should be added in the future. It currently uses the active mission
See also
[andes_db_connect()] for getting a connection object to the ANDES database.
Other Andesdb query functions:
get_andes_catch(),
get_andes_mission(),
get_biodiv_data()