Create a WKT linestring for an Andes set
make_set_wkt.RdThis function creates a WKT (Well-Known Text) representation of a linestring connecting the start and end coordinates of a fishing set from the Andes database.
make_set_wkt.RdThis function creates a WKT (Well-Known Text) representation of a linestring connecting the start and end coordinates of a fishing set from the Andes database.