rbind, but allow different columns names Make a union of the rows filling missing columns with NA https://stackoverflow.com/questions/3402371/combine-two-data-frames-by-rows-rbind-when-they-have-different-sets-of-columns
row_union.Rdrbind, but allow different columns names Make a union of the rows filling missing columns with NA https://stackoverflow.com/questions/3402371/combine-two-data-frames-by-rows-rbind-when-they-have-different-sets-of-columns